[pitivi] Fix source comment typos
- From: Alexandru Băluț <alexbalut src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [pitivi] Fix source comment typos
- Date: Mon, 26 Aug 2019 20:10:41 +0000 (UTC)
commit 37c053ab7084202996ec07a5869ddabd6496d08f
Author: luz.paz <luzpaz users noreply github com>
Date: Mon Aug 26 14:13:19 2019 -0400
Fix source comment typos
Found via ` codespell -q 3 -S *.po -L dur,que,uint`
build/flatpak/pitivi-flatpak | 2 +-
docs/Development_workflow.md | 2 +-
docs/design/2008_design/2008_Architectural_Redesign/Browsers.md | 2 +-
.../design/2008_design/2008_Architectural_Redesign/Design_Thoughts.md | 2 +-
docs/design/2008_design/2008_Plugin_Interface_development.md | 2 +-
docs/design/Plugins.md | 4 ++--
pitivi/render.py | 4 ++--
7 files changed, 9 insertions(+), 9 deletions(-)
---
diff --git a/build/flatpak/pitivi-flatpak b/build/flatpak/pitivi-flatpak
index a693bf94..677f211e 100755
--- a/build/flatpak/pitivi-flatpak
+++ b/build/flatpak/pitivi-flatpak
@@ -156,7 +156,7 @@ def check_flatpak(verbose=True):
if verbose:
Console.message("\n%sYou need to install %s >= %s"
" to be able to use the '%s' script.\n\n"
- "You can find some informations about"
+ "You can find some information about"
" how to install it for your distribution at:\n"
" * http://flatpak.org/%s\n", Colors.FAIL,
app, required_version, sys.argv[0], Colors.ENDC)
diff --git a/docs/Development_workflow.md b/docs/Development_workflow.md
index 3e67cfe9..887d1b2d 100644
--- a/docs/Development_workflow.md
+++ b/docs/Development_workflow.md
@@ -54,7 +54,7 @@ want to create.
1. In the [GitLab UI](https://gitlab.gnome.org/GNOME/pitivi) press the "fork"
button (*WARNING: Make sure to be authenticated otherwise the button won't be
- avalaible*)
+ available*)
2. Add the remote git repository you just forked as a remote to your local git repository:
diff --git a/docs/design/2008_design/2008_Architectural_Redesign/Browsers.md
b/docs/design/2008_design/2008_Architectural_Redesign/Browsers.md
index 23148090..76d12629 100644
--- a/docs/design/2008_design/2008_Architectural_Redesign/Browsers.md
+++ b/docs/design/2008_design/2008_Architectural_Redesign/Browsers.md
@@ -51,7 +51,7 @@ The browsers CAN also offer these functionality:
`ObjectFactory` with the given uri. It returns an `ObjectFactory`
which might be the same as the input, or a new one, or a a temporary
new one.
-- Searching/Browsing functionnalities
+- Searching/Browsing functionalities
Browsers should use the **UI Bundle** system to provide adequate UI
interfaces if needed.
diff --git a/docs/design/2008_design/2008_Architectural_Redesign/Design_Thoughts.md
b/docs/design/2008_design/2008_Architectural_Redesign/Design_Thoughts.md
index 64bbe398..d0acc28a 100644
--- a/docs/design/2008_design/2008_Architectural_Redesign/Design_Thoughts.md
+++ b/docs/design/2008_design/2008_Architectural_Redesign/Design_Thoughts.md
@@ -169,7 +169,7 @@ It seriously needs to be rethinked.
of an audio track)
- The 'media-converted' ones could maybe done on the fly
if you add a file of a given media type (ex:audio) into
- a track of anothe media type (ex:video).
+ a track of another media type (ex:video).
- Allow easy transcoding, re-rendering or re-muxing of
SubObjectFactory.
- Allow adding extra (meta)data
diff --git a/docs/design/2008_design/2008_Plugin_Interface_development.md
b/docs/design/2008_design/2008_Plugin_Interface_development.md
index 6e5a4c70..38e9515c 100644
--- a/docs/design/2008_design/2008_Plugin_Interface_development.md
+++ b/docs/design/2008_design/2008_Plugin_Interface_development.md
@@ -121,7 +121,7 @@ configuration dialog.
### Current implementation
-The current implimentation is a mix-in object that replaces the
+The current implementation is a mix-in object that replaces the
configure() method with our own gui-builder code (plugin authors that
need more flexibility can create their own configure() method)
diff --git a/docs/design/Plugins.md b/docs/design/Plugins.md
index 02aeeb50..70b7f745 100644
--- a/docs/design/Plugins.md
+++ b/docs/design/Plugins.md
@@ -2,7 +2,7 @@
The PiTiVi plugin system will help keep the core to a minimum codebase
required for normal editing. The plugins will add various kind of
-functionnalities/interfaces for new features, special hardwares, online
+functionalities/interfaces for new features, special hardwares, online
services, ....
# Use Cases for Plugins
@@ -307,7 +307,7 @@ the most freedom.
The main advantage of using interfaces over class inheritance is that
the former defines relationships between items and keeps the system
-higly decoupled, while the latter constrains thee partecipants to a gree
+highly decoupled, while the latter constrains thee partecipants to a gree
an “is a” relationship, thus creating strong coupling between classes.
# Pluggable architecture proposal
diff --git a/pitivi/render.py b/pitivi/render.py
index 06f6743e..e3216473 100644
--- a/pitivi/render.py
+++ b/pitivi/render.py
@@ -47,9 +47,9 @@ from pitivi.utils.widgets import TextWidget
class Encoders(Loggable):
- """Registry of avalaible Muxers, Audio encoders and Video encoders.
+ """Registry of available Muxers, Audio encoders and Video encoders.
- Also keeps the avalaible combinations of those.
+ Also keeps the available combinations of those.
It is a singleton. Use `Encoders()` to access the instance.
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]